Learn R Programming

tigris (version 1.6.1)

load_tiger_doc_template: Documentation Template for Functions that Utilize load_tiger

Description

Documentation Template for Functions that Utilize load_tiger

Arguments

...

arguments to be passed to internal function load_tiger, which is not exported. See Additional Arguments.

year

the data year; defaults to 2020

Additional Arguments

Additional arguments that can be passed in ... are:

  • class Desired class of return object: "sf" (the default) or "sp".

  • progress_bar If set to FALSE, do not display download progress bar (helpful for R Markdown documents). Defaults to TRUE.

  • keep_zipped_shapefile If set to TRUE, do not delete zipped shapefile (stored in temporary directory or TIGRIS_CACHE_DIR depending on the configuration of global option "tigris_use_cache"). Defaults to FALSE.

  • refresh Whether to re-download cached shapefiles (TRUE or FALSE) . The default is either FALSE or the value of global option "tigris_refresh" if it is set. Specifying this argument will override the behavior set in "tigris_refresh" global option.

Details

This documentation is inherited by tigris functions that wrap load_tiger. Include the following in function documentation: @inheritParams load_tiger_doc_template @inheritSection load_tiger_doc_template Additional Arguments