Learn R Programming

tigris (version 1.6.1)

alaska_native_regional_corporations: Download an Alaska Native Regional Corporation shapefile into R.

Description

From the US Census Bureau: "ANRCs are corporations created according to the Alaska Native Claims Settlement Act. They are organized under the laws of the State of Alaska as "Regional Corporations," to conduct both the for-profit and non-profit affairs of Alaska Natives within defined regions of Alaska." For more information, please see the Census technical documentation at the link provided.

Usage

alaska_native_regional_corporations(cb = FALSE, year = NULL, ...)

Arguments

cb

If cb is set to TRUE, download a generalized (1:500k) file. Defaults to FALSE (the most detailed TIGER/Line file)

year

the data year; defaults to 2020

...

arguments to be passed to internal function load_tiger, which is not exported. See Additional Arguments.

Additional Arguments

Additional arguments that can be passed in ... are:

  • class Desired class of return object: "sf" (the default) or "sp".

  • progress_bar If set to FALSE, do not display download progress bar (helpful for R Markdown documents). Defaults to TRUE.

  • keep_zipped_shapefile If set to TRUE, do not delete zipped shapefile (stored in temporary directory or TIGRIS_CACHE_DIR depending on the configuration of global option "tigris_use_cache"). Defaults to FALSE.

  • refresh Whether to re-download cached shapefiles (TRUE or FALSE) . The default is either FALSE or the value of global option "tigris_refresh" if it is set. Specifying this argument will override the behavior set in "tigris_refresh" global option.

See Also

https://www2.census.gov/geo/pdfs/reference/GARM/Ch5GARM.pdf

Other native/tribal geometries functions: native_areas(), tribal_block_groups(), tribal_census_tracts(), tribal_subdivisions_national()