Learn R Programming

tigris (version 1.6.1)

county_subdivisions: Download a county subdivision shapefile into R

Description

From the US Census Bureau (see link for source, and more information): "All counties and statistically equivalent entities consist of one or more geographic units that the Bureau of the Census recognizes as county subdivisions. The two major types of county subdivisions are minor civil divisions(MCDs) and census county divisions (CCDs). A State has either MCDs or their statistical equivalents, or CCDs; it cannot contain both."

Usage

county_subdivisions(state, county = NULL, cb = FALSE, year = NULL, ...)

Arguments

state

The two-digit FIPS code (string) of the state you want. Can also be state name or state abbreviation.

county

The three-digit FIPS code (string) of the county you'd like to subset for, or a vector of FIPS codes if you desire multiple counties. Can also be a county name or vector of names.

cb

If cb is set to TRUE, download a generalized (1:500k) file. Defaults to FALSE (the most detailed TIGER/Line file)

year

the data year; defaults to 2020

...

arguments to be passed to internal function load_tiger, which is not exported. See Additional Arguments.

Additional Arguments

Additional arguments that can be passed in ... are:

  • class Desired class of return object: "sf" (the default) or "sp".

  • progress_bar If set to FALSE, do not display download progress bar (helpful for R Markdown documents). Defaults to TRUE.

  • keep_zipped_shapefile If set to TRUE, do not delete zipped shapefile (stored in temporary directory or TIGRIS_CACHE_DIR depending on the configuration of global option "tigris_use_cache"). Defaults to FALSE.

  • refresh Whether to re-download cached shapefiles (TRUE or FALSE) . The default is either FALSE or the value of global option "tigris_refresh" if it is set. Specifying this argument will override the behavior set in "tigris_refresh" global option.

See Also

https://www2.census.gov/geo/pdfs/reference/GARM/Ch8GARM.pdf

Other general area functions: block_groups(), blocks(), counties(), places(), pumas(), school_districts(), states(), tracts(), zctas()

Examples

Run this code
if (FALSE) {
library(tigris)

or <- county_subdivisions('Oregon', c('Linn', 'Benton'))

plot(or$geometry)

}

Run the code above in your browser using DataLab