primary_roads: Download a national primary roads shapefile into R
Description
From the Census Bureau: "Primary roads are generally divided,
limited-access highways within the Federal interstate highway
system or under state management. These highways are distinguished by the
presence of interchanges
and are accessible by ramps and may include some toll highways."
Usage
primary_roads(year = NULL, ...)
Arguments
year
the data year; defaults to 2020
...
arguments to be passed to internal function load_tiger, which is not exported. See Additional Arguments.
Additional Arguments
Additional arguments that can be passed in ... are:
class Desired class of return object: "sf" (the default) or "sp".
progress_bar If set to FALSE, do not display download progress bar (helpful for R Markdown documents). Defaults to TRUE.
keep_zipped_shapefile If set to TRUE, do not delete zipped shapefile (stored in temporary directory or TIGRIS_CACHE_DIR
depending on the configuration of global option "tigris_use_cache"). Defaults to FALSE.
refresh Whether to re-download cached shapefiles (TRUE or FALSE) . The default is either FALSE or the value of global
option "tigris_refresh" if it is set. Specifying this argument will override the behavior set in "tigris_refresh" global option.