Learn R Programming

tigris (version 0.1)

tigris-exports: tigris exported operators

Description

The following functions are imported and then re-exported from the tigris package to enable use of the magrittr pipe operator with no additional library calls

Arguments